@@ -6,7 +6,7 @@ from PIL import Image, ImageDraw, ImageFont, ImageOps
 WIDTH = 300
 HEIGHT = 90
 FONT_SIZE = 16
-FONT = 'font.ttf'
+FONT = 'resources/font.ttf'
 
 
 def draw_date(draw: ImageDraw, date: datetime):
